@@ -13,18 +13,18 @@
 
 // =================================================================== //
 
-#ifdef __GNUG__
-# include <cassert>
-# include <cstdio>
-# include <cstdlib>
-# include <cstring>
-# include <fstream.h>
-#else
+#ifdef __BORLANDC__
 # include <assert>
 # include <stdio>
 # include <stdlib>
 # include <string>
 # include <fstream>
+#else
+# include <cassert>
+# include <cstdio>
+# include <cstdlib>
+# include <cstring>
+# include <fstream>
 #endif
 
 #if !CXX_NO_NAMESPACE
@@ -1107,7 +1107,7 @@ int Beamline::set_value(
 ) {
     const Value* curvalue = ti->get_varval(varname);
     if (curvalue == nil) {
-	return Beamline::BAD_VARIABLE;
+	return BAD_VARIABLE;
     }
     int retcode = OK;
     Value* newval = curvalue->clone();
@@ -1453,6 +1453,35 @@ int Beamline::load_scr_from_oe(const OE* oelem, Screen* screen) {
     return 0;
 }
 
+// 
+// fix_modified_surface_read_flags: When reading a new OE namelist, turn 
+// on FDUMMY (see ERROR page in shadow menu) when any one of the modified 
+// surface flags are turned on.
+//
+// Necessary due to the inability of SHADOW's menu format to change the
+// the value of one variable when some other value changes.
+//
+// Also see fix_modified_surface_write_flags() for the converse.
+//
+static int fix_modified_surface_read_flags(Beamline* bline, int oe) {
+    const char* dummy_value = bline->get_oe_value(oe, "FDUMMY");
+    const char* f_ripple = bline->get_oe_value(oe, "F_RIPPLE");
+    const char* f_facet = bline->get_oe_value(oe, "F_FACET");
+    const char* f_roughness = bline->get_oe_value(oe, "F_ROUGHNESS");
+    const char* f_koma = bline->get_oe_value(oe, "F_KOMA");
+    const char* f_segment = bline->get_oe_value(oe, "F_SEGMENT");
+    if (
+	(f_ripple    && strcasecmp(f_ripple,    "YES") == 0) ||
+	(f_facet     && strcasecmp(f_facet,     "YES") == 0) ||
+	(f_roughness && strcasecmp(f_roughness, "YES") == 0) ||
+	(f_koma      && strcasecmp(f_koma,      "YES") == 0) ||
+	(f_segment   && strcasecmp(f_segment,   "YES") == 0)
+    ) {
+	bline->set_oe_value(oe, "FDUMMY", "YES");
+    }
+    return 0;
+}
+
 int Beamline::load_oe(const string& file, int oe) {
     remove_oe(oe);
     add_oe(oe, oe);
@@ -1460,6 +1489,12 @@ int Beamline::load_oe(const string& file, int oe) {
     if (load_nml(file, oelem) == -1)
 	return -1;
 
+    //
+    // Now we check the FDUMMY that controls "Modified Surface", and
+    // turn off all the modified surface attributes if FDUMMY is false.
+    // UNCONST
+    fix_modified_surface_read_flags(this, oe);
+
     //
     // trivial case: no screens.
     //
@@ -1582,6 +1617,28 @@ int Beamline::store_source(const string& file) const {
     return (src_) ? store_nml(file, get_source()) : -1;
 }
 
+//
+// fix_modified_surface_write_flags: When writing a OE namelist, turn off 
+// ALL the modified surface flags (eg., F_SEGMENT) when FDUMMY (see ERROR 
+// page in shadow menu) is turned off. 
+//
+// Necessary due to the inability of SHADOW's menu format to change the
+// the value of one variable when some other value changes.
+//
+// Also see fix_modified_surface_read_flags() for the converse.
+//
+static int fix_modified_surface_write_flags(Beamline* bline, int oe) {
+    const char* dummy_value = bline->get_oe_value(oe, "FDUMMY");
+    if (strcasecmp(dummy_value, "NO") == 0) {
+	bline->set_oe_value(oe, "F_RIPPLE",   "NO");
+	bline->set_oe_value(oe, "F_FACET",    "NO");
+	bline->set_oe_value(oe, "F_ROUGNESS", "NO");
+	bline->set_oe_value(oe, "F_KOMA",     "NO");
+	bline->set_oe_value(oe, "F_SEGMENT",  "NO");
+    }
+    return 0;
+}
+
 int Beamline::store_oe(const string& file, int oe) const {
     const OE* oelem = get_oe(oe);
     if (oe == nil)
@@ -1605,6 +1662,13 @@ int Beamline::store_oe(const string& file, int oe) const {
     sprintf(value, "%d", numscrn);
     this_bline->set_oe_value(oe, "N_SCREEN", value);
 
+    //
+    // Now we check the FDUMMY that controls "Modified Surface", and
+    // turn off all the modified surface attributes if FDUMMY is false.
+    //
+    fix_modified_surface_write_flags(this_bline, oe);
+
+
     if (numscrn == 0) {
         return store_nml(file, oelem);
     }
