@@ -7,6 +7,10 @@
 #include <string>
 
 template class deque<void*>;
+
+/* Not needed for SGI STL and egcs */
+#ifndef __STL_CONFIG_H
+
 template bool operator!=(
     deque<void*>::iterator const &,
     deque<void*>::iterator const &
@@ -19,8 +23,10 @@ template bool operator!=(
     deque<void*>::const_iterator const &, 
     deque<void *>::iterator const &
 );
+#endif /* __STL_CONFIG_H */
 
 template class list<void*>;
+#ifndef __STL_CONFIG_H
 template bool operator!=(
     list<void*>::const_iterator const &, 
     list<void*>::const_iterator const &
@@ -29,11 +35,13 @@ template bool operator!=(
     list<void*>::const_iterator const &, 
     list<void*>::iterator const &
 );
+#endif /* __STL_CONFIG_H */
 
 template class less<string>;
 template class less<Mystring>;
 
 template class list<string>;
+#ifndef __STL_CONFIG_H
 template bool operator!=(
     list<string>::const_iterator const &, 
     list<string>::const_iterator const &
@@ -42,8 +50,10 @@ template bool operator!=(
     list<string>::const_iterator const &, 
     list<string>::iterator const &
 );
+#endif /* __STL_CONFIG_H */
 
 template class map<string, void*, less<string> >;
+#ifndef __STL_CONFIG_H
 template class rb_tree<string, pair<string const, void*>, 
     select1st<pair<string const, void*>, string>, less<string> >;
 
@@ -70,11 +80,13 @@ template bool operator!=(rb_tree<string, pair<string const, void *>,
     rb_tree<string, pair<string const, void *>,
     select1st<pair<string const, void *>, string>,
     less<string > >::iterator const &);
+#endif /* __STL_CONFIG_H */
 
 //
 // need for ToolMgr::map<Mystring, Mystring, less<Mystring> >
 //
 template class map<Mystring, Mystring, less<Mystring> >;
+#ifndef __STL_CONFIG_H
 template class rb_tree<Mystring, pair<Mystring const, Mystring>, 
     select1st<pair<Mystring const, Mystring>, Mystring>, less<Mystring> >;
 
@@ -84,12 +96,13 @@ template bool operator!=(rb_tree<Mystring, pair<Mystring const, Mystring>,
     rb_tree<Mystring, pair<Mystring const, Mystring>, 
     select1st<pair<Mystring const, Mystring>, Mystring>, 
     less<Mystring> >::const_iterator const &);
+#endif /* __STL_CONFIG_H */
 
 //
 // When compiling with -O on an HP, this one is needed in addition to
 // all the rest below.
 //
-#if defined(__hppa)
+#if defined(__hppa) || defined(__sgi__)
 template void max(unsigned int const &, unsigned int const &);
 #endif
 
