@@ -166,6 +166,7 @@ OE      Z_ROT           R       0.0
 OE      Z_SOUR          R       0.0       
 OE      Z_SOUR_ROT      R       0.0              
 SCR     FILE_ABS        F       NONE SPECIFIED      
+SCR     FILE_SCR_EXT    F       NONE SPECIFIED      
 SCR     I_ABS           Y       OFF      
 SCR     I_SCREEN        E       BEFORE      
 SCR     I_SLIT          Y       OFF      
@@ -173,6 +174,8 @@ SCR     I_STOP          E       SLIT
 SCR     K_SLIT          E       RECT      
 SCR     RX_SLIT         R       10.0      
 SCR     RZ_SLIT         R       10.0      
+SCR     CX_SLIT         R       0.0      
+SCR     CZ_SLIT         R       0.0      
 SCR     SCR_NUMBER      I       0        
 SCR     SL_DIS          R       0.0      
 SCR     THICK           R       0.0      
@@ -228,6 +231,16 @@ SRC     PH6             R       10.0
 SRC     PH7             R       10.0      
 SRC     PH8             R       10.0      
 SRC     PH9             R       10.0      
+SRC     RL1             R       1.0      
+SRC     RL10            R       1.0      
+SRC     RL2             R       1.0      
+SRC     RL3             R       1.0      
+SRC     RL4             R       1.0      
+SRC     RL5             R       1.0      
+SRC     RL6             R       1.0      
+SRC     RL7             R       1.0      
+SRC     RL8             R       1.0      
+SRC     RL9             R       1.0      
 SRC     POL_ANGLE       R       0.0         
 SRC     POL_DEG         R       0.0         
 SRC     R_ALADDIN       R       208.33        
@@ -297,7 +310,7 @@ PLX     PLX_HIST_YCTR   R       0.0
 PLX     PLX_HIST_YWID   R       0.0
 PLX     PLX_HIST_XBINS  I       25
 PLX     PLX_HIST_YBINS  I       25
-#if __CYGWIN32__
+#if _WIN32
 PLX     PLX_DEVICE      E       Postscript
 #else
 PLX     PLX_DEVICE      E       X Windows
@@ -337,7 +350,7 @@ PL2     PL2_HIST_YCTR   R       0.0
 PL2     PL2_HIST_YWID   R       0.0
 PL2     PL2_HIST_XBINS  I       25
 PL2     PL2_HIST_YBINS  I       25
-#if __CYGWIN32__
+#if _WIN32
 PL2     PL2_DEVICE      E       Postscript
 #else
 PL2     PL2_DEVICE      E       X Windows
@@ -377,7 +390,7 @@ PL3     PL3_HIST_YCTR   R       0.0
 PL3     PL3_HIST_YWID   R       0.0
 PL3     PL3_HIST_XBINS  I       25
 PL3     PL3_HIST_YBINS  I       25
-#if __CYGWIN32__
+#if _WIN32
 PL3     PL3_DEVICE      E       Postscript
 #else
 PL3     PL3_DEVICE      E       X Windows
@@ -490,6 +503,7 @@ F_COLOR         OFF             00
 F_COLOR         SLINE           01              
 F_COLOR         MLINE           02              
 F_COLOR         CONTINUOUS      03              
+F_COLOR         REL_MLINE       04              
 
 F_CONVEX        CONCAVE         00              
 F_CONVEX        CONVEX          01              
@@ -892,15 +906,30 @@ SET     %E      OE      FMIRR           EQ              CODLING
 SET     %F      OE      FMIRR           EQ              TOROIDA       
 SET     %G      OE      FMIRR           EQ              HYPERBO       
 SET     %H      OE      FMIRR           EQ              CONICAL       
+SET     %I      %B                      OR      %G    
 DATA OE   Y     FMIRR                   Type selected              
 DATA OE  D      RMIRR                   Spherical radius              
-DATA OE  B      AXMAJ                   Ellipse major Axis              
-DATA OE  B      AXMIN                            minor Axis              
-DATA OE  B      ELL_THE                 Angle of MajAx and Pole [CCW]    
+*
+* Workaround for "same variable name" bug. See below.
+*
+DATA OE  I      AXMAJ                   Ellipse/Hyperbola major Axis 
+DATA OE  I      AXMIN                              minor axis    
+DATA OE  I      ELL_THE                 Angle of MajAx and Pole [CCW]    
+*
+* There is a bug that causes neither Elliptical nor Hyperbolical params
+* to show up since both have the same variable names. FIXME.
+*DATA OE  B      AXMAJ                   Ellipse major Axis              
+*DATA OE  B      AXMIN                            minor Axis              
+*DATA OE  B      ELL_THE                 Angle of MajAx and Pole [CCW]    
+*
 DATA OE  A      PARAM                   Paraboloid param.              
-DATA OE  G      AXMAJ                   Hyperbola major Axis              
-DATA OE  G      AXMIN                              minor axis    
-DATA OE  G      ELL_THE                 Angle of MajAx and Pole [CCW]    
+*
+* There is a bug that causes neither Elliptical nor Hyperbolical params
+* to show up since both have the same variable names. FIXME.
+*DATA OE  G      AXMAJ                   Hyperbola major Axis              
+*DATA OE  G      AXMIN                              minor axis    
+*DATA OE  G      ELL_THE                 Angle of MajAx and Pole [CCW]    
+*
 DATA OE  F      R_MAJ                   Torus major Radius              
 DATA OE  F      R_MIN                          minor Radius              
 DATA OE  H      CONE_A                  Cone half-aperture [deg]              
@@ -937,12 +966,13 @@ DATA OE  A      Y_SOUR_ROT                                         Y
 DATA OE  A      Z_SOUR_ROT                                          Z    
                
 MENU OE         ERROR                   Surface Changes
+SET     %A      OE      FDUMMY          EQ              YES 
 SKIP
-DATA OE         F_RIPPLE                Surface error                    RIPPLE
-DATA OE         F_FACET                 Faceted Surface                  FACET 
-DATA OE         F_ROUGHNESS             Surface Roughness                ROUGH
-DATA OE         F_KOMA                  Kumakhov lens                    KOMA
-DATA OE         F_SEGMENT               Segmented Mirror                 SEGMENT
+DATA OE  A      F_RIPPLE                Surface error                    RIPPLE
+DATA OE  A      F_FACET                 Faceted Surface                  FACET 
+DATA OE  A      F_ROUGHNESS             Surface Roughness                ROUGH
+DATA OE  A      F_KOMA                  Kumakhov lens                    KOMA
+DATA OE  A      F_SEGMENT               Segmented Mirror                 SEGMENT
 
 MENU OE         RIPPLE                  Surface Quality              
 SET     %A      OE      F_RIPPLE        EQ              YES 
@@ -1217,10 +1247,13 @@ SET     %A      SRC     F_COLOR         NE              OFF
 SET     %B      SRC     F_COLOR         EQ              SLINE     
 SET     %C      SRC     F_COLOR         EQ              MLINE     
 SET     %D      SRC     F_COLOR         EQ              CONTINUOUS     
+SET     %J      SRC     F_COLOR         EQ              REL_MLINE
 SET     %S      SRC     FDISTR          NE              EXACT-SR   
 SET     %E      %D                      OR      %C     
+SET     %E      %E                      OR      %J     
 SET     %G      %E                      OR      %B   
-SET     %H      %C                      AND     %S   
+SET     %K      %C                      OR      %J   
+SET     %H      %K                      AND     %S   
 SET     %I      %E                      AND     %S   
 SKIP     
 DATA SRC  Y     F_COLOR                 Energy distribution     
@@ -1236,6 +1269,25 @@ DATA SRC H      PH7                            7
 DATA SRC H      PH8                            8     
 DATA SRC H      PH9                            9     
 DATA SRC H      PH10                          10     
+SKIP     
+DATA SRC J      F_COLOR                 Relative Intensities             RELINT
+
+MENU            RELINT                  Relative Multi-line
+SET     %A      SRC     F_COLOR         EQ              REL_MLINE
+SKIP     
+DATA SRC  Y     F_COLOR                 Energy distribution     
+DATA SRC AY     F_PHOT                  Units      
+DATA SRC AY     N_COLOR                 Number of lines to use     
+DATA SRC A      RL1                     Line # 1     
+DATA SRC A      RL2                            2     
+DATA SRC A      RL3                            3     
+DATA SRC A      RL4                            4     
+DATA SRC A      RL5                            5     
+DATA SRC A      RL6                            6     
+DATA SRC A      RL7                            7     
+DATA SRC A      RL8                            8     
+DATA SRC A      RL9                            9     
+DATA SRC A      RL10                          10     
 
 MENU OE         SHAPE                   Mirror Shape              
 SET     %A      OE      FHIT_C          EQ              ON 
@@ -1385,13 +1437,20 @@ DATA GTO        NUMB                    New OE
 MENU SCR        SCR_DATA                View Screen/Slit Data              
 SET     %A      SCR     I_SLIT          EQ              ON    
 SET     %B      SCR     I_ABS           EQ              ON      
+SET     %C      SCR     K_SLIT          NE              EXTERNAL      
+SET     %D      SCR     K_SLIT          EQ              EXTERNAL
+SET     %E      %A                      AND     %C
+SET     %F      %A                      AND     %D
 DATA SCR        I_SCREEN                Position rel. to mirror      
 DATA SCR        SL_DIS                  Distance (abs) from mirror   
 DATA SCR  Y     I_SLIT                  Aperturing   
 DATA SCR A      I_STOP                  Open slit/ solid stop      
-DATA SCR A      K_SLIT                  Aperture shape      
-DATA SCR A      RX_SLIT                 Slit width/  x-axis      
-DATA SCR A      RZ_SLIT                 Slit heigth/ z-axis      
+DATA SCR AY     K_SLIT                  Aperture shape      
+DATA SCR E      RX_SLIT                 Slit width/  x-axis      
+DATA SCR E      RZ_SLIT                 Slit heigth/ z-axis      
+DATA SCR E      CX_SLIT                      center/  x-axis      
+DATA SCR E      CZ_SLIT                      center/  z-axis      
+DATA SCR F      FILE_SCR_EXT            External file with coordinates
 DATA SCR  Y     I_ABS                   Absorption      
 DATA SCR B      THICK                   Thickness [ CM ]   
 DATA SCR B      FILE_ABS                Opt. Const. File-name      
@@ -1420,7 +1479,7 @@ DATA PLX        PLX_SCALE_OPTS          What kind of scaling to use      PLX_SCA
 DATA PLX        PLX_DO_HIST             Draw the histograms?             PLX_HISTO
 DATA PLX   Y    PLX_PLOT_TYPE           Kind of plot                     PLX_PLWHAT
 TEXT                                    Other hairy options you can set  PLX_OPTS
-#if __CYGWIN32__
+#if _WIN32
 SKIP
 TEXT                                    If you choose X Window display,
 TEXT                                    make sure your X Windows Server
