@@ -11,14 +11,14 @@
 // Copyright (c) 1994 Mumit Khan
 //
 
-#ifdef __GNUG__
-# include <cassert>
-# include <cstdlib>
-# include <cstring>
-#else
+#ifdef __BORLANDC__
 # include <assert>
 # include <stdlib>
 # include <string>
+#else
+# include <cassert>
+# include <cstdlib>
+# include <cstring>
 #endif
 
 #if !CXX_NO_NAMESPACE
@@ -789,8 +789,6 @@ static int set_value_msg(Tcl_Interp* interp,
 		varname, "\".", (char*) NULL
 	    );
 	    break;
-	case Beamline::ERROR:
-	    // FALL THRU
 	default:
 	    Tcl_AppendResult(interp, 
 		"ERROR: Cannot set value \"", value, "\" for Namelist item \"", 
